@@ -116,11 +116,13 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     # Models with common features
     "H6008": BASIC_CAPABILITIES,
     "H600D": BASIC_CAPABILITIES,
+    "H6020": create_with_capabilities(True, True, True, 0, True),
     "H6022": BASIC_CAPABILITIES,
     "H6039": create_with_capabilities(True, True, True, 12, True),
     "H6042": create_with_capabilities(True, True, True, 5, True),
     "H6046": create_with_capabilities(True, True, True, 10, True),
-    "H6047": BASIC_CAPABILITIES,
+    "H6047": create_with_capabilities(True, True, True, 10, True),
+    "H6048": create_with_capabilities(True, True, True, 24, True),
     "H6051": BASIC_CAPABILITIES,
     "H6052": BASIC_CAPABILITIES,
     "H6056": BASIC_CAPABILITIES,
@@ -134,27 +136,29 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H6069": create_with_capabilities(True, False, True, 20, True),
     "H6067": BASIC_CAPABILITIES,
     "H606A": BASIC_CAPABILITIES,
-    "H6088": BASIC_CAPABILITIES,
+    "H6088": create_with_capabilities(True, True, True, 6, True),
     "H608A": BASIC_CAPABILITIES,
     "H6079": BASIC_CAPABILITIES,
     "H607C": BASIC_CAPABILITIES,
-    "H608B": BASIC_CAPABILITIES,
+    "H608B": create_with_capabilities(True, True, True, 15, True),
     "H608D": BASIC_CAPABILITIES,
-    "H60A1": BASIC_CAPABILITIES,
+    "H60A1": create_with_capabilities(True, True, True, 13, True),
     "H60A4": create_with_capabilities(True, True, True, 11, False),
-    "H60A6": BASIC_CAPABILITIES,
-    "H6072": BASIC_CAPABILITIES,
+    "H60A6": create_with_capabilities(True, True, True, 0, False),
+    "H60B1": create_with_capabilities(True, True, True, 3, True),
+    "H60B2": create_with_capabilities(True, True, True, 3, True),
+    "H6072": create_with_capabilities(True, True, True, 8, True),
     "H6073": BASIC_CAPABILITIES,
     "H6076": BASIC_CAPABILITIES,
     "H6078": BASIC_CAPABILITIES,
-    "H6087": BASIC_CAPABILITIES,
+    "H6087": create_with_capabilities(True, True, True, 12, True),
     "H610A": BASIC_CAPABILITIES,
     "H610B": BASIC_CAPABILITIES,
     "H6110": BASIC_CAPABILITIES,
     "H6117": BASIC_CAPABILITIES,
     "H612A": BASIC_CAPABILITIES,
     "H612B": BASIC_CAPABILITIES,
-    "H612C": create_with_capabilities(True, True, True, 0, True),
+    "H612C": create_with_capabilities(True, True, True, 10, True),
     "H612D": create_with_capabilities(True, True, True, 20, True),
     "H612F": create_with_capabilities(True, True, True, 5, True),
     "H6143": BASIC_CAPABILITIES,
@@ -168,6 +172,7 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H6163": BASIC_CAPABILITIES,
     "H6167": create_with_capabilities(True, True, True, 12, True),
     "H6168": BASIC_CAPABILITIES,
+    "H6169": create_with_capabilities(True, True, True, 15, True),
     "H6172": BASIC_CAPABILITIES,
     "H6173": BASIC_CAPABILITIES,
     "H6175": BASIC_CAPABILITIES,
@@ -191,6 +196,8 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H61B2": BASIC_CAPABILITIES,
     "H61B3": create_with_capabilities(True, True, True, 15, True),
     "H61B5": BASIC_CAPABILITIES,
+    "H61B6": create_with_capabilities(True, True, True, 0, True),
+    "H61B9": create_with_capabilities(True, True, True, 0, True),
     "H61BA": BASIC_CAPABILITIES,
     "H61BE": BASIC_CAPABILITIES,
     "H61BC": BASIC_CAPABILITIES,
@@ -210,15 +217,21 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H6609": create_with_capabilities(True, True, True, 18, True),
     "H6640": create_with_capabilities(True, True, True, 8, True),
     "H6641": create_with_capabilities(True, True, True, 14, True),
+    "H6810": create_with_capabilities(True, True, True, 0, False),
+    "H6871": create_with_capabilities(True, True, True, 0, True),
     "H7012": create_with_capabilities(False, False, True, 0, False),
     "H7013": create_with_capabilities(False, False, True, 0, False),
     "H7021": BASIC_CAPABILITIES,
     "H7025": create_with_capabilities(True, False, True, 15, True),
+    "H7026": create_with_capabilities(True, False, True, 30, True),
     "H7028": BASIC_CAPABILITIES,
+    "H702B": create_with_capabilities(True, True, True, 0, True),
     "H7041": BASIC_CAPABILITIES,
     "H7042": BASIC_CAPABILITIES,
     "H7050": BASIC_CAPABILITIES,
     "H7051": BASIC_CAPABILITIES,
+    "H7053": create_with_capabilities(True, True, True, 0, True),
+    "H7057": create_with_capabilities(True, True, True, 0, True),
     "H7058": create_with_capabilities(True, True, True, 0, True),
     "H7055": BASIC_CAPABILITIES,
     "H705A": BASIC_CAPABILITIES,
@@ -237,6 +250,7 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H706A": BASIC_CAPABILITIES,
     "H706B": BASIC_CAPABILITIES,
     "H706C": BASIC_CAPABILITIES,
+    "H7086": create_with_capabilities(True, True, True, 0, True),
     "H7093": create_with_capabilities(True, True, True, 2, True),
     "H7033": BASIC_CAPABILITIES,
     "H70C1": BASIC_CAPABILITIES,
@@ -247,17 +261,20 @@ GOVEE_LIGHT_CAPABILITIES: dict[str, GoveeLightCapabilities] = {
     "H7037": BASIC_CAPABILITIES,
     "H7038": BASIC_CAPABILITIES,
     "H7039": create_with_capabilities(True, True, True, 45, True),
-    "H7052": BASIC_CAPABILITIES,
+    "H7052": create_with_capabilities(True, True, True, 15, True),
     "H7075": BASIC_CAPABILITIES,
+    "H7076": create_with_capabilities(True, True, True, 15, True),
     "H70A1": create_with_capabilities(True, True, True, 15, True),
     "H70A2": create_with_capabilities(True, True, True, 20, True),
     "H70A3": create_with_capabilities(True, True, True, 15, True),
     "H70B1": BASIC_CAPABILITIES,
     "H70B3": BASIC_CAPABILITIES,
+    "H70B6": create_with_capabilities(True, True, True, 0, True),
     "H70BC": BASIC_CAPABILITIES,
     "H70D1": BASIC_CAPABILITIES,
     "H8022": BASIC_CAPABILITIES,
+    "H80C5": create_with_capabilities(True, True, True, 10, True),
     "H805A": create_with_capabilities(True, True, True, 0, True),
-    "H805C": BASIC_CAPABILITIES,
+    "H805C": create_with_capabilities(True, True, True, 9, True),
     "H8072": create_with_capabilities(True, True, True, 8, True),
 }
